[−][src]Function jsonschema_valid::validate
pub fn validate(
instance: &Value,
schema: &Value,
draft: Option<&dyn Draft>,
validate_schema: bool
) -> ValidationErrors
Validates a given JSON instance against a given JSON schema, returning the errors, if any. draft may provide the schema draft to use. If not provided, it will be determined automatically from the schema.
Arguments
instance: The JSON document to validateschema: The JSON schema to validate againstdraft: The draft of the JSON schema specification to use. IfNone, the draft will be automatically determined from theschema.validate_schema: Whentrue, validate the schema against the metaschema first.
Returns
errors: A vector ofValidationErrorfound during validation.